/**
 * @license
 * Copyright 2022-2026 Matter.js Authors
 * SPDX-License-Identifier: Apache-2.0
 */
import { MaybePromise, StorageContext, StorageManager } from "@matter/general";
/**
 * Non-volatile state management for a {@link ControllerNode}.
 */
export declare class ControllerStore implements ControllerStoreInterface {
    #private;
    /**
     * Create a new store.
     *
     * TODO - implement conversion from 0.7 format so people can change API seamlessly
     */
    constructor(nodeId: string, storageManager: StorageManager);
    erase(): Promise<void>;
    close(): Promise<void>;
    get sessionStorage(): StorageContext;
    get caStorage(): StorageContext;
    get nodesStorage(): StorageContext;
    get fabricStorage(): StorageContext;
    get storage(): StorageManager;
    clientNodeStore(nodeId: string): Promise<StorageContext>;
}
export declare abstract class ControllerStoreInterface {
    abstract erase(): Promise<void>;
    abstract close(): Promise<void>;
    abstract get sessionStorage(): StorageContext;
    abstract get caStorage(): StorageContext;
    abstract get nodesStorage(): StorageContext;
    abstract get fabricStorage(): StorageContext;
    abstract clientNodeStore(nodeId: string): MaybePromise<StorageContext>;
}
//# sourceMappingURL=ControllerStore.d.ts.map